@@ -1210,15 +1210,21 @@ def rel_spiral_fermat(detectors, x_motor, y_motor, x_range, y_range, dr,
     '''
     _md = {'plan_name': 'rel_spiral_fermat'}
     _md.update(md or {})
-    return (yield from spiral_fermat(detectors, x_motor, y_motor,
-                                     x_motor.position,
-                                     y_motor.position, x_range,
-                                     y_range, dr, factor, tilt=tilt,
-                                     per_step=per_step, md=_md))
+
+    @bpp.reset_positions_decorator([x_motor, y_motor])
+    @bpp.relative_set_decorator([x_motor, y_motor])
+    def inner_relative_spiral_fermat():
+        return (yield from spiral_fermat(detectors, x_motor, y_motor,
+                                         0, 0,
+                                         x_range, y_range,
+                                         dr, factor, tilt=tilt,
+                                         per_step=per_step, md=_md))
+
+    return (yield from inner_relative_spiral_fermat())
 
 
 def spiral(detectors, x_motor, y_motor, x_start, y_start, x_range, y_range, dr,
-           nth, *, tilt=0.0, per_step=None, md=None):
+           nth, *, dr_y=None, tilt=0.0, per_step=None, md=None):
     '''Spiral scan, centered around (x_start, y_start)
 
     Parameters
@@ -1236,7 +1242,10 @@ def spiral(detectors, x_motor, y_motor, x_start, y_start, x_range, y_range, dr,
     y_range : float
         y width of spiral
     dr : float
-        Delta radius
+        Delta radius along the minor axis of the ellipse. 
+    dr_y : float, optional
+        Delta radius along the major axis of the ellipse. If None, defaults to
+        dr.
     nth : float
         Number of theta steps
     tilt : float, optional
@@ -1256,7 +1265,7 @@ def spiral(detectors, x_motor, y_motor, x_start, y_start, x_range, y_range, dr,
     '''
     pattern_args = dict(x_motor=x_motor, y_motor=y_motor, x_start=x_start,
                         y_start=y_start, x_range=x_range, y_range=y_range,
-                        dr=dr, nth=nth, tilt=tilt)
+                        dr=dr, nth=nth, dr_y=dr_y, tilt=tilt)
     cyc = plan_patterns.spiral(**pattern_args)
 
     # Before including pattern_args in metadata, replace objects with reprs.
@@ -1266,7 +1275,7 @@ def spiral(detectors, x_motor, y_motor, x_start, y_start, x_range, y_range, dr,
                          'x_motor': repr(x_motor), 'y_motor': repr(y_motor),
                          'x_start': x_start, 'y_start': y_start,
                          'x_range': x_range, 'y_range': y_range,
-                         'dr': dr, 'nth': nth, 'tilt': tilt,
+                         'dr': dr, 'dr_y': dr_y, 'nth': nth, 'tilt': tilt,
                          'per_step': repr(per_step)},
            'extents': tuple([[x_start - x_range, x_start + x_range],
                              [y_start - y_range, y_start + y_range]]),
@@ -1289,7 +1298,8 @@ def spiral(detectors, x_motor, y_motor, x_start, y_start, x_range, y_range, dr,
 
 
 def rel_spiral(detectors, x_motor, y_motor, x_range, y_range, dr, nth,
-               *, tilt=0.0, per_step=None, md=None):
+               *, dr_y=None, tilt=0.0, per_step=None, md=None):
+
     '''Relative spiral scan
 
     Parameters
@@ -1307,7 +1317,10 @@ def rel_spiral(detectors, x_motor, y_motor, x_range, y_range, dr, nth,
     y_range : float
         y width of spiral
     dr : float
-        Delta radius
+        Delta radius along the minor axis of the ellipse. 
+    dr_y : float, optional
+        Delta radius along the major axis of the ellipse. If None, it
+        defaults to dr.
     nth : float
         Number of theta steps
     tilt : float, optional
@@ -1324,12 +1337,139 @@ def rel_spiral(detectors, x_motor, y_motor, x_range, y_range, dr, nth,
     :func:`bluesky.plans.spiral`
     :func:`bluesky.plans.spiral_fermat`
     '''
-    _md = {'plan_name': 'rel_spiral_fermat'}
+    _md = {'plan_name': 'rel_spiral'}
     _md.update(md or {})
-    return (yield from spiral(detectors, x_motor, y_motor,
-                              x_motor.position, y_motor.position,
-                              x_range, y_range, dr, nth, tilt=tilt,
-                              per_step=per_step, md=_md))
+
+    @bpp.reset_positions_decorator([x_motor, y_motor])
+    @bpp.relative_set_decorator([x_motor, y_motor])
+    def inner_relative_spiral():
+        return (yield from spiral(detectors, x_motor, y_motor,
+                                  0, 0,
+                                  x_range, y_range, dr, nth,
+                                  dr_y=dr_y, tilt=tilt,
+                                  per_step=per_step, md=_md))
+
+    return (yield from inner_relative_spiral())
+
+
+def spiral_square(detectors, x_motor, y_motor, x_center, y_center, x_range,
+                  y_range, x_num, y_num, *, per_step=None, md=None):
+    '''Absolute square spiral scan, centered around (x_center, y_center)
+
+    Parameters
+    ----------
+    detectors : list
+        list of 'readable' objects
+    x_motor : object
+        any 'setable' object (motor, temp controller, etc.)
+    y_motor : object
+        any 'setable' object (motor, temp controller, etc.)
+    x_center : float
+        x center
+    y_center : float
+        y center
+    x_range : float
+        x width of spiral
+    y_range : float
+        y width of spiral
+    x_num : float
+        number of x axis points
+    y_num : float
+        Number of y axis points.
+    per_step : callable, optional
+        hook for cutomizing action of inner loop (messages per step)
+        See docstring of bluesky.plans.one_nd_step (the default) for
+        details.
+    md : dict, optional
+        metadata
+
+    See Also
+    --------
+    :func:`bluesky.plans.relative_spiral_square`
+    :func:`bluesky.plans.spiral`
+    :func:`bluesky.plans.relative_spiral`
+    :func:`bluesky.plans.spiral_fermat`
+    :func:`bluesky.plans.relative_spiral_fermat`
+    '''
+    pattern_args = dict(x_motor=x_motor, y_motor=y_motor, x_center=x_center,
+                        y_center=y_center, x_range=x_range, y_range=y_range,
+                        x_num=x_num, y_num=y_num)
+    cyc = plan_patterns.spiral_square_pattern(**pattern_args)
+
+    # Before including pattern_args in metadata, replace objects with reprs.
+    pattern_args['x_motor'] = repr(x_motor)
+    pattern_args['y_motor'] = repr(y_motor)
+    _md = {'plan_args': {'detectors': list(map(repr, detectors)),
+                         'x_motor': repr(x_motor), 'y_motor': repr(y_motor),
+                         'x_center': x_center, 'y_center': y_center,
+                         'x_range': x_range, 'y_range': y_range,
+                         'x_num': x_num, 'y_num': y_num,
+                         'per_step': repr(per_step)},
+           'plan_name': 'spiral_square',
+           'plan_pattern': 'spiral_square',
+           'shape': (y_num, x_num),
+           'extents': ((y_center - y_range / 2, y_center + y_range / 2),
+                       (x_center - x_range / 2, x_center + x_range / 2)),
+           'hints': {},
+           }
+    _md.update(md or {})
+    _md['hints'].setdefault('gridding', 'rectilinear_nonsequential')
+    try:
+        _md['hints'].setdefault('dimensions', [(m.hints['fields'], 'primary')
+                                               for m in [y_motor, x_motor]])
+    except (AttributeError, KeyError):
+        ...
+
+    return (yield from scan_nd(detectors, cyc, per_step=per_step, md=_md))
+
+
+def rel_spiral_square(detectors, x_motor, y_motor, x_range, y_range,
+                      x_num, y_num, *, per_step=None, md=None):
+    '''Relative square spiral scan, centered around current (x, y) position.
+
+    Parameters
+    ----------
+    detectors : list
+        list of 'readable' objects
+    x_motor : object
+        any 'setable' object (motor, temp controller, etc.)
+    y_motor : object
+        any 'setable' object (motor, temp controller, etc.)
+    x_range : float
+        x width of spiral
+    y_range : float
+        y width of spiral
+    x_num : float
+        number of x axis points
+    y_num : float
+        Number of y axis points.
+    per_step : callable, optional
+        hook for cutomizing action of inner loop (messages per step)
+        See docstring of bluesky.plans.one_nd_step (the default) for
+        details.
+    md : dict, optional
+        metadata
+
+    See Also
+    --------
+    :func:`bluesky.plans.spiral_square`
+    :func:`bluesky.plans.spiral`
+    :func:`bluesky.plans.relative_spiral`
+    :func:`bluesky.plans.spiral_fermat`
+    :func:`bluesky.plans.relative_spiral_fermat`
+    '''
+    _md = {'plan_name': 'rel_spiral_square'}
+    _md.update(md or {})
+
+    @bpp.reset_positions_decorator([x_motor, y_motor])
+    @bpp.relative_set_decorator([x_motor, y_motor])
+    def inner_relative_spiral():
+        return (yield from spiral_square(detectors, x_motor, y_motor,
+                                         0, 0,
+                                         x_range, y_range, x_num, y_num,
+                                         per_step=per_step, md=_md))
+
+    return (yield from inner_relative_spiral())
 
 
 def ramp_plan(go_plan,
@@ -1442,6 +1582,52 @@ def fly(flyers, *, md=None):
     yield from bps.close_run()
 
 
+def x2x_scan(detectors, motor1, motor2, start, stop, num, *,
+             per_step=None, md=None):
+    """
+    Relatively scan over two motors in a 2:1 ratio
+
+    This is a generalized version of a theta2theta scan
+
+    Parameters
+    ----------
+    detectors : list
+        list of 'readable' objects
+
+    motor1, motor2 : Positioner
+        The second motor will move half as much as the first
+
+    start, stop : float
+        The relative limits of the first motor.  The second motor
+        will move between ``start / 2`` and ``stop / 2``
+
+    per_step : callable, optional
+        hook for cutomizing action of inner loop (messages per step)
+        See docstring of bluesky.plan_stubs.one_nd_step (the default) for
+        details.
+
+    md : dict, optional
+        metadata
+
+
+    """
+    _md = {'plan_name': 'x2x_scan',
+           'plan_args': {'detectors': list(map(repr, detectors)),
+                         'motor1': motor1.name,
+                         'motor2': motor2.name,
+                         'start': start, 'stop': stop, 'num': num,
+                         'per_step': repr(per_step)}
+           }
+
+    _md.update(md or {})
+    return (yield from relative_inner_product_scan(
+        detectors, num,
+        motor1, start, stop,
+        motor2, start / 2, stop / 2,
+        per_step=per_step,
+        md=_md))
+
+
 relative_list_scan = rel_list_scan  # back-compat
 relative_scan = rel_scan  # back-compat
 relative_log_scan = rel_log_scan  # back-compat
